==> haskell-monad-time-0.3.1.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-time
version:              0.3.1.0
visibility:           public
id:                   monad-time-0.3.1.0-3d4yAlPjz8P33AmXrmtMWL
key:                  monad-time-0.3.1.0-3d4yAlPjz8P33AmXrmtMWL
license:              BSD-3-Clause
copyright:            Scrive AB
maintainer:
    Andrzej Rybczak <andrzej@rybczak.net>,
    Jonathan Jouty <jonathan@scrive.com>,
    Mikhail Glushenkov <mikhail@scrive.com>

author:               Andrzej Rybczak
homepage:             https://github.com/scrive/monad-time
synopsis:
    Type class for monads which carry
    the notion of the current time.

description:
    '\''MonadTime'\'' type class for monads
    which carry the notion of the current time.

category:             Control
abi:                  605f2c65976b03a69535d88a24000244
exposed:              True
exposed-modules:      Control.Monad.Time
import-dirs:          /usr/lib/ghc-8.10.4/site-local/monad-time-0.3.1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/monad-time-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/monad-time-0.3.1.0
hs-libraries:         HSmonad-time-0.3.1.0-3d4yAlPjz8P33AmXrmtMWL
depends:              base-4.14.1.0 mtl-2.2.2 time-1.9.3
haddock-interfaces:   /usr/share/doc/haskell-monad-time/html/monad-time.haddock
haddock-html:         /usr/share/doc/haskell-monad-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-time-0.3.1.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-time
version:              0.3.1.0
visibility:           public
id:                   monad-time-0.3.1.0-35smlGNocUd6H7P1jwmOgV
key:                  monad-time-0.3.1.0-35smlGNocUd6H7P1jwmOgV
license:              BSD-3-Clause
copyright:            Scrive AB
maintainer:
    Andrzej Rybczak <andrzej@rybczak.net>,
    Jonathan Jouty <jonathan@scrive.com>,
    Mikhail Glushenkov <mikhail@scrive.com>

author:               Andrzej Rybczak
homepage:             https://github.com/scrive/monad-time
synopsis:
    Type class for monads which carry
    the notion of the current time.

description:
    '\''MonadTime'\'' type class for monads
    which carry the notion of the current time.

category:             Control
abi:                  0bb88d7667b974194f7abd88fd3c9f7b
exposed:              True
exposed-modules:      Control.Monad.Time
import-dirs:          /usr/lib/ghc-8.10.5/site-local/monad-time-0.3.1.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/monad-time-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/monad-time-0.3.1.0
hs-libraries:         HSmonad-time-0.3.1.0-35smlGNocUd6H7P1jwmOgV
depends:              base-4.14.2.0 mtl-2.2.2 time-1.9.3
haddock-interfaces:   /usr/share/doc/haskell-monad-time/html/monad-time.haddock
haddock-html:         /usr/share/doc/haskell-monad-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
